==> openGion_dev_5.3.4.0.zip: opengion/uap/webapps/gf/db/oracle/sql/05_SRC/DYDIFF.sql <==
/**********************************************************************/
/* ɂ̍߂܂B                                           */
/* A}CiXɂ́AO ƂĕԂ܂B                      */
/*          DYDIFF( DATE1,[DATE2],[PLUS] )                            */
/*                                                                    */
/*	  DATE1      IN VARCHAR2  YYYYMMDD ` ̕                  */
/*	 [DATE2]     IN VARCHAR2  YYYYMMDD ` ̕ [{]           */
/*	 [PLUS]      IN NUMBER    tvZɉZ  [=0]        */
/*                                                                    */
/*	 ^[l   DATE1-DATE2+PLUS i0ȏ̐j                    */
/*                                                                    */
/*	DATE1DATE2̍ij߂܂B                              */
/*  DATE2ZbgȂꍇ́A{̓tŌvZ܂B             */
/*  Kg`[g̉ʕ\p̍vZł̂ŁA}CiXl        */
/*	0 ƂĕԂ܂B                                                */
/*  ͂̏ԂɂӂB                                      */
/*                                                                    */
/**********************************************************************/
CREATE OR REPLACE FUNCTION DYDIFF(
	DATE1   IN VARCHAR2  ,
	DATE2   IN VARCHAR2 := NULL ,
	PLUS    IN NUMBER   := 0 )
RETURN NUMBER
IS
    RTN     NUMBER(4);

BEGIN

	IF DATE2 IS NULL THEN
		RTN := TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD') - TRUNC(SYSDATE) + PLUS;
	ELSE
		RTN := TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD' ) - TO_DATE( SUBSTRB(DATE2,1,8),'YYYYMMDD' ) + PLUS;
	END IF;

	IF RTN < 0 THEN RTN := 0; END IF;

	RETURN RTN;

END DYDIFF;
/

==> openGion_dev_5.3.5.0.zip: opengion/uap/webapps/gf/db/oracle/sql/05_SRC/DYDIFF.sql <==
/**********************************************************************/
/* ɂ̍߂܂B                                           */
/* A}CiXɂ́AO ƂĕԂ܂B                      */
/*          DYDIFF( DATE1,[DATE2],[PLUS] )                            */
/*                                                                    */
/*	  DATE1      IN VARCHAR2  YYYYMMDD ` ̕                  */
/*	 [DATE2]     IN VARCHAR2  YYYYMMDD ` ̕ [{]           */
/*	 [PLUS]      IN NUMBER    tvZɉZ  [=0]        */
/*                                                                    */
/*	 ^[l   DATE1-DATE2+PLUS i0ȏ̐j                    */
/*                                                                    */
/*	DATE1DATE2̍ij߂܂B                              */
/*  DATE2ZbgȂꍇ́A{̓tŌvZ܂B             */
/*  Kg`[g̉ʕ\p̍vZł̂ŁA}CiXl        */
/*	0 ƂĕԂ܂B                                                */
/*  ͂̏ԂɂӂB                                      */
/*                                                                    */
/**********************************************************************/
CREATE OR REPLACE FUNCTION DYDIFF(
	DATE1   IN VARCHAR2  ,
	DATE2   IN VARCHAR2 := NULL ,
	PLUS    IN NUMBER   := 0 )
RETURN NUMBER
IS
    RTN     NUMBER(4);

BEGIN

	IF DATE2 IS NULL THEN
-- 5.3.5.0 (2011/05/01) vZ̃oOC
--		RTN := TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD') - TRUNC(SYSDATE) + PLUS;
		RTN := MONTHS_BETWEEN(TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD' ),TRUNC(SYSDATE))*30 + PLUS;
	ELSE
-- 5.3.5.0 (2011/05/01) vZ̃oOC
--		RTN := TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD' ) - TO_DATE( SUBSTRB(DATE2,1,8),'YYYYMMDD' ) + PLUS;
		RTN := MONTHS_BETWEEN(TO_DATE( SUBSTRB(DATE1,1,8),'YYYYMMDD' ),TO_DATE( SUBSTRB(DATE2,1,8),'YYYYMMDD' ))*30 + PLUS;
	END IF;

	IF RTN < 0 THEN RTN := 0; END IF;

	RETURN RTN;

END DYDIFF;
/
